@@ -1,40 +1,46 @@
+from typing import Literal, Optional
+from beartype import beartype
 from pglet.control import Control
 
-# Footer
-class Footer(Control):
-    def __init__(self, id=None, controls=None):
-        Control.__init__(self, id=id)
-    
-        self.__controls = []
-        if controls != None:
-            for control in controls:
-                self.__controls.append(control)
+TYPE = Literal[None, "normal", "largeHeader", "close"]
 
-    # controls
-    @property
-    def controls(self):
-        return self.__controls
-
-    @controls.setter
-    def controls(self, value):
-        self.__controls = value
-
-    def _get_control_name(self):
-        return "footer"
-
-    def _get_children(self):
-        return self.__controls
 
 class Dialog(Control):
-    def __init__(self, id=None, open=None, title=None, sub_text=None, type=None,
-            auto_dismiss=None, width=None, max_width=None, height=None, fixed_top=None,
-            blocking=None, data=None, controls=None, footer=None, on_dismiss=None,
-            padding=None, margin=None, visible=None, disabled=None):
-        
-        Control.__init__(self, id=id,
-            width=width, height=height, padding=padding, margin=margin,
-            visible=visible, disabled=disabled, data=data)
-        
+    def __init__(
+        self,
+        id=None,
+        open=None,
+        title=None,
+        sub_text=None,
+        type: TYPE = None,
+        auto_dismiss=None,
+        width=None,
+        max_width=None,
+        height=None,
+        fixed_top=None,
+        blocking=None,
+        data=None,
+        controls=None,
+        footer=None,
+        on_dismiss=None,
+        padding=None,
+        margin=None,
+        visible=None,
+        disabled=None,
+    ):
+
+        Control.__init__(
+            self,
+            id=id,
+            width=width,
+            height=height,
+            padding=padding,
+            margin=margin,
+            visible=visible,
+            disabled=disabled,
+            data=data,
+        )
+
         self.open = open
         self.title = title
         self.sub_text = sub_text
@@ -65,8 +71,8 @@ class Dialog(Control):
     # footer
     @property
     def footer(self):
-        return self.__footer 
-    
+        return self.__footer
+
     # on_dismiss
     @property
     def on_dismiss(self):
@@ -82,8 +88,8 @@ class Dialog(Control):
         return self._get_attr("open")
 
     @open.setter
-    def open(self, value):
-        assert value == None or isinstance(value, bool), "open must be a boolean"
+    @beartype
+    def open(self, value: Optional[bool]):
         self._set_attr("open", value)
 
     # title
@@ -110,7 +116,8 @@ class Dialog(Control):
         return self._get_attr("type")
 
     @type.setter
-    def type(self, value):
+    @beartype
+    def type(self, value: TYPE):
         self._set_attr("type", value)
 
     # auto_dismiss
@@ -119,8 +126,8 @@ class Dialog(Control):
         return self._get_attr("autoDismiss")
 
     @auto_dismiss.setter
-    def auto_dismiss(self, value):
-        assert value == None or isinstance(value, bool), "autoDismiss must be a boolean"
+    @beartype
+    def auto_dismiss(self, value: Optional[bool]):
         self._set_attr("autoDismiss", value)
 
     # max_width
@@ -138,8 +145,8 @@ class Dialog(Control):
         return self._get_attr("fixedTop")
 
     @fixed_top.setter
-    def fixed_top(self, value):
-        assert value == None or isinstance(value, bool), "fixed_top must be a boolean"
+    @beartype
+    def fixed_top(self, value: Optional[bool]):
         self._set_attr("fixedTop", value)
 
     # blocking
@@ -148,14 +155,39 @@ class Dialog(Control):
         return self._get_attr("blocking")
 
     @blocking.setter
-    def blocking(self, value):
-        assert value == None or isinstance(value, bool), "blocking must be a boolean"
+    @beartype
+    def blocking(self, value: Optional[bool]):
         self._set_attr("blocking", value)
 
     def _get_children(self):
-        result=[]
+        result = []
         if self.__controls and len(self.__controls) > 0:
             for control in self.__controls:
                 result.append(control)
         result.append(self.__footer)
-        return result
\ No newline at end of file
+        return result
+
+
+class Footer(Control):
+    def __init__(self, id=None, controls=None):
+        Control.__init__(self, id=id)
+
+        self.__controls = []
+        if controls != None:
+            for control in controls:
+                self.__controls.append(control)
+
+    # controls
+    @property
+    def controls(self):
+        return self.__controls
+
+    @controls.setter
+    def controls(self, value):
+        self.__controls = value
+
+    def _get_control_name(self):
+        return "footer"
+
+    def _get_children(self):
+        return self.__controls
