@@ -1,49 +1,67 @@
+from typing import Literal, Optional, Union
+from beartype import beartype
 from pglet.control import Control
 
-# Point
-class Point(Control):
-    def __init__(self, id=None, x=None, y=None, tick=None, legend=None,
-        x_tooltip=None, y_tooltip=None):
-        Control.__init__(self, id=id)
+X_TYPE = Literal[None, "number", "date"]
+
+
+class LineChart(Control):
+    def __init__(
+        self,
+        id=None,
+        legend=None,
+        tooltips=None,
+        stroke_width=None,
+        y_min=None,
+        y_max=None,
+        y_ticks=None,
+        y_format=None,
+        x_type: X_TYPE = None,
+        lines=None,
+        width=None,
+        height=None,
+        padding=None,
+        margin=None,
+        visible=None,
+        disabled=None,
+    ):
+
+        Control.__init__(
+            self,
+            id=id,
+            width=width,
+            height=height,
+            padding=padding,
+            margin=margin,
+            visible=visible,
+            disabled=disabled,
+        )
+
+        self.__lines = []
+        if lines != None:
+            for line in lines:
+                self.__lines.append(line)
 
-        self.x = x
-        self.y = y
-        self.tick = tick
         self.legend = legend
-        self.x_tooltip = x_tooltip
-        self.y_tooltip = y_tooltip
+        self.tooltips = tooltips
+        self.stroke_width = stroke_width
+        self.y_min = y_min
+        self.y_max = y_max
+        self.y_ticks = y_ticks
+        self.y_format = y_format
+        self.x_type = x_type
 
     def _get_control_name(self):
-        return "p"
+        return "linechart"
 
-    # x
+    # lines
     @property
-    def x(self):
-        return self._get_attr("x")
+    def lines(self):
+        return self.__lines
 
-    @x.setter
-    def x(self, value):
-        #assert value == None or isinstance(value, float) or isinstance(value, int), "x must be a float"  
-        self._set_attr("x", value)
-
-    # y
-    @property
-    def y(self):
-        return self._get_attr("y")
-
-    @y.setter
-    def y(self, value):
-        assert value == None or isinstance(value, float) or isinstance(value, int), "y must be a float"    
-        self._set_attr("y", value)
-
-    # tick
-    @property
-    def tick(self):
-        return self._get_attr("tick")
-
-    @tick.setter
-    def tick(self, value):
-        self._set_attr("tick", value)
+    @lines.setter
+    def lines(self, value):
+        self.__lines = value
 
     # legend
     @property
@@ -51,32 +69,87 @@ class Point(Control):
         return self._get_attr("legend")
 
     @legend.setter
-    def legend(self, value):
+    @beartype
+    def legend(self, value: Optional[bool]):
         self._set_attr("legend", value)
 
-    # x_tooltip
+    # tooltips
     @property
-    def x_tooltip(self):
-        return self._get_attr("xTooltip")
+    def tooltips(self):
+        return self._get_attr("tooltips")
 
-    @x_tooltip.setter
-    def x_tooltip(self, value):
-        self._set_attr("xTooltip", value)
+    @tooltips.setter
+    @beartype
+    def tooltips(self, value: Optional[bool]):
+        self._set_attr("tooltips", value)
 
-    # y_tooltip
+    # stroke_width
     @property
-    def y_tooltip(self):
-        return self._get_attr("yTooltip")
+    def stroke_width(self):
+        return self._get_attr("strokeWidth")
+
+    @stroke_width.setter
+    @beartype
+    def stroke_width(self, value: Optional[int]):
+        self._set_attr("strokeWidth", value)
+
+    # y_min
+    @property
+    def y_min(self):
+        return self._get_attr("yMin")
+
+    @y_min.setter
+    @beartype
+    def y_min(self, value: Union[None, int, float]):
+        self._set_attr("yMin", value)
+
+    # y_max
+    @property
+    def y_max(self):
+        return self._get_attr("yMax")
+
+    @y_max.setter
+    @beartype
+    def y_max(self, value: Union[None, int, float]):
+        self._set_attr("yMax", value)
+
+    # y_ticks
+    @property
+    def y_ticks(self):
+        return self._get_attr("yTicks")
+
+    @y_ticks.setter
+    @beartype
+    def y_ticks(self, value: Optional[int]):
+        self._set_attr("yTicks", value)
+
+    # y_format
+    @property
+    def y_format(self):
+        return self._get_attr("yFormat")
+
+    @y_format.setter
+    def y_format(self, value):
+        self._set_attr("yFormat", value)
+
+    # x_type
+    @property
+    def x_type(self):
+        return self._get_attr("xType")
+
+    @x_type.setter
+    @beartype
+    def x_type(self, value: X_TYPE):
+        self._set_attr("xType", value)
+
+    def _get_children(self):
+        return self.__lines
 
-    @y_tooltip.setter
-    def y_tooltip(self, value):
-        self._set_attr("yTooltip", value)
 
-# Data
 class Data(Control):
     def __init__(self, id=None, color=None, legend=None, points=None):
         Control.__init__(self, id=id)
-    
+
         self.color = color
         self.legend = legend
         self.__points = []
@@ -118,40 +191,56 @@ class Data(Control):
         return self.__points
 
 
-class LineChart(Control):
-    def __init__(self, id=None, legend=None, tooltips=None, stroke_width=None, 
-            y_min=None, y_max=None, y_ticks=None, y_format=None, x_type=None, lines=None,
-            width=None, height=None, padding=None, margin=None, visible=None, disabled=None):
-        
-        Control.__init__(self, id=id,
-            width=width, height=height, padding=padding, margin=margin,
-            visible=visible, disabled=disabled)
-
-        self.__lines = []
-        if lines != None:
-            for line in lines:
-                self.__lines.append(line)
+class Point(Control):
+    def __init__(
+        self,
+        id=None,
+        x=None,
+        y=None,
+        tick=None,
+        legend=None,
+        x_tooltip=None,
+        y_tooltip=None,
+    ):
+        Control.__init__(self, id=id)
 
+        self.x = x
+        self.y = y
+        self.tick = tick
         self.legend = legend
-        self.tooltips = tooltips
-        self.stroke_width = stroke_width
-        self.y_min = y_min
-        self.y_max = y_max
-        self.y_ticks = y_ticks
-        self.y_format = y_format
-        self.x_type = x_type
-        
+        self.x_tooltip = x_tooltip
+        self.y_tooltip = y_tooltip
+
     def _get_control_name(self):
-        return "linechart"
+        return "p"
 
-    # lines
+    # x
     @property
-    def lines(self):
-        return self.__lines
+    def x(self):
+        return self._get_attr("x")
 
-    @lines.setter
-    def lines(self, value):
-        self.__lines = value
+    @x.setter
+    def x(self, value):
+        self._set_attr("x", value)
+
+    # y
+    @property
+    def y(self):
+        return self._get_attr("y")
+
+    @y.setter
+    @beartype
+    def y(self, value: Union[None, int, float]):
+        self._set_attr("y", value)
+
+    # tick
+    @property
+    def tick(self):
+        return self._get_attr("tick")
+
+    @tick.setter
+    def tick(self, value):
+        self._set_attr("tick", value)
 
     # legend
     @property
@@ -160,76 +249,22 @@ class LineChart(Control):
 
     @legend.setter
     def legend(self, value):
-        assert value == None or isinstance(value, bool), "legend must be a boolean"
         self._set_attr("legend", value)
 
-    # tooltips
+    # x_tooltip
     @property
-    def tooltips(self):
-        return self._get_attr("tooltips")
+    def x_tooltip(self):
+        return self._get_attr("xTooltip")
 
-    @tooltips.setter
-    def tooltips(self, value):
-        assert value == None or isinstance(value, bool), "tooltips must be a boolean"
-        self._set_attr("tooltips", value)
+    @x_tooltip.setter
+    def x_tooltip(self, value):
+        self._set_attr("xTooltip", value)
 
-    # stroke_width
+    # y_tooltip
     @property
-    def stroke_width(self):
-        return self._get_attr("strokeWidth")
+    def y_tooltip(self):
+        return self._get_attr("yTooltip")
 
-    @stroke_width.setter
-    def stroke_width(self, value):
-        assert value == None or isinstance(value, int), "stroke_width must be a int"   
-        self._set_attr("strokeWidth", value)
-
-    # y_min
-    @property
-    def y_min(self):
-        return self._get_attr("yMin")
-
-    @y_min.setter
-    def y_min(self, value):
-        assert value == None or isinstance(value, float) or isinstance(value, int), "y_min must be a float"  
-        self._set_attr("yMin", value)
-
-    # y_max
-    @property
-    def y_max(self):
-        return self._get_attr("yMax")
-
-    @y_max.setter
-    def y_max(self, value):
-        assert value == None or isinstance(value, float) or isinstance(value, int), "y_max must be a float"  
-        self._set_attr("yMax", value)
-
-    # y_ticks
-    @property
-    def y_ticks(self):
-        return self._get_attr("yTicks")
-
-    @y_ticks.setter
-    def y_ticks(self, value):
-        assert value == None or isinstance(value, int), "y_ticks must be a int"  
-        self._set_attr("yTicks", value)
-
-    # y_format
-    @property
-    def y_format(self):
-        return self._get_attr("yFormat")
-
-    @y_format.setter
-    def y_format(self, value):
-        self._set_attr("yFormat", value)
-
-    # x_type
-    @property
-    def x_type(self):
-        return self._get_attr("xType")
-
-    @x_type.setter
-    def x_type(self, value):
-        self._set_attr("xType", value)
-
-    def _get_children(self):
-        return self.__lines
+    @y_tooltip.setter
+    def y_tooltip(self, value):
+        self._set_attr("yTooltip", value)
