@@ -82,7 +82,7 @@ class SearchBox(Control):
     # value
     @property
     def value(self):
-        return self._get_attr("value")
+        return self._get_attr("value", def_value="")
 
     @value.setter
     def value(self, value):
