@@ -1,13 +1,41 @@
+from typing import Literal, Union
+from beartype import beartype
 from pglet.control import Control
 
+POSITION = Literal[None, "left", "top", "right", "bottom"]
+
+
 class SpinButton(Control):
-    def __init__(self, label=None, id=None, value=None, min=None, max=None, step=None,
-            icon=None, label_position=None, data=None, on_change=None,
-            width=None, height=None, padding=None, margin=None,
-            visible=None, disabled=None):
-        Control.__init__(self, id=id,
-            width=width, height=height, padding=padding, margin=margin,
-            visible=visible, disabled=disabled, data=data)
+    def __init__(
+        self,
+        label=None,
+        id=None,
+        value=None,
+        min=None,
+        max=None,
+        step=None,
+        icon=None,
+        label_position: POSITION = None,
+        data=None,
+        on_change=None,
+        width=None,
+        height=None,
+        padding=None,
+        margin=None,
+        visible=None,
+        disabled=None,
+    ):
+        Control.__init__(
+            self,
+            id=id,
+            width=width,
+            height=height,
+            padding=padding,
+            margin=margin,
+            visible=visible,
+            disabled=disabled,
+            data=data,
+        )
         self.value = value
         self.label = label
         self.label_position = label_position
@@ -20,7 +48,7 @@ class SpinButton(Control):
     def _get_control_name(self):
         return "spinbutton"
 
-# on_change
+    # on_change
     @property
     def on_change(self):
         return self._get_event_handler("change")
@@ -29,17 +57,17 @@ class SpinButton(Control):
     def on_change(self, handler):
         self._add_event_handler("change", handler)
 
-# value
+    # value
     @property
     def value(self):
         return self._get_attr("value", data_type="float")
 
     @value.setter
-    def value(self, value):
-        assert value == None or isinstance(value, float) or isinstance(value, int), "value must be a float"
+    @beartype
+    def value(self, value: Union[None, int, float]):
         self._set_attr("value", value)
 
-# label
+    # label
     @property
     def label(self):
         return self._get_attr("label")
@@ -48,50 +76,51 @@ class SpinButton(Control):
     def label(self, value):
         self._set_attr("label", value)
 
-# label_position
+    # label_position
     @property
     def label_position(self):
         return self._get_attr("labelposition")
 
     @label_position.setter
-    def label_position(self, value):
-        self._set_attr("labelposition", value)        
+    @beartype
+    def label_position(self, value: POSITION):
+        self._set_attr("labelposition", value)
 
-# min
+    # min
     @property
     def min(self):
         return self._get_attr("min")
 
     @min.setter
-    def min(self, value):
-        assert value == None or isinstance(value, float) or isinstance(value, int), "min must be a float"
+    @beartype
+    def min(self, value: Union[None, int, float]):
         self._set_attr("min", value)
 
-# max
+    # max
     @property
     def max(self):
         return self._get_attr("max")
 
     @max.setter
-    def max(self, value):
-        assert value == None or isinstance(value, float) or isinstance(value, int), "max must be a float"
+    @beartype
+    def max(self, value: Union[None, int, float]):
         self._set_attr("max", value)
 
-# step
+    # step
     @property
     def step(self):
         return self._get_attr("step")
 
     @step.setter
-    def step(self, value):
-        assert value == None or isinstance(value, float) or isinstance(value, int), "step must be a float"
+    @beartype
+    def step(self, value: Union[None, int, float]):
         self._set_attr("step", value)
 
-# icon
+    # icon
     @property
     def icon(self):
         return self._get_attr("icon")
 
     @icon.setter
     def icon(self, value):
-        self._set_attr("icon", value)
\ No newline at end of file
+        self._set_attr("icon", value)
