@@ -1,12 +1,14 @@
-import pytest
 import pglet
+import pytest
 from pglet import Textbox
 
+
 @pytest.fixture
 def page():
-    return pglet.page('test_update', local=True, no_window=True)
+    return pglet.page("test_update", local=True, no_window=True)
+
 
 def test_update_single_control(page):
     txt = Textbox(id="txt1", label="First name:")
     page.add(txt)
-    page.update(txt)
\ No newline at end of file
+    page.update(txt)
